Class: AllDrill

Inherits:
Drill show all
Defined in:
lib/ruby_drills/array/all_drill.rb

Constant Summary

Constants included from Commands

Commands::GAMBLER

Instance Attribute Summary

Attributes inherited from Drill

#hints, #next, #previous

Instance Method Summary collapse

Methods inherited from Drill

#done?, #drills, #expected, #initialize

Methods included from Commands

#back, #clear, #continue, #fail, #fold, #help, #hint, #quit, #review, #skip, #welcome, #win

Constructor Details

This class inherits a constructor from Drill

Instance Method Details

#referenceObject



20
21
22
# File 'lib/ruby_drills/array/all_drill.rb', line 20

def reference
  "@values.all?"
end

#setupObject



3
4
5
6
7
# File 'lib/ruby_drills/array/all_drill.rb', line 3

def setup
  @values = [ nil, true, 99 ]
  @hints = ["The method you'll use takes an optional block. Optional.",
                "http://ruby-doc.org/core-1.9.3/Enumerable.html#method-i-all-3F"]
end

#showObject



9
10
11
12
13
14
15
16
17
18
# File 'lib/ruby_drills/array/all_drill.rb', line 9

def show
  puts %{
@values = #{@values.inspect}

Does this array contain values that are false or nil?

Use the method that will return true only if none of the collection
members are false or nil. No block is necessary to answer this:
}
end

#valid?(input) ⇒ Boolean

Returns:

  • (Boolean)


24
25
26
# File 'lib/ruby_drills/array/all_drill.rb', line 24

def valid?(input)
  input.include?("all?")
end