Class: MapDrill
- Inherits:
-
Drill
show all
- Defined in:
- lib/ruby_drills/array/map_drill.rb
Constant Summary
Constants included
from Commands
Commands::GAMBLER
Instance Attribute Summary
Attributes inherited from Drill
#hints, #next, #previous
Instance Method Summary
collapse
Methods inherited from Drill
#done?, #drills, #expected, #initialize, #non!
Methods included from Commands
#back, #clear, #continue, #fail, #fold, #help, #hint, #quit, #review, #skip, #welcome, #win
Constructor Details
This class inherits a constructor from Drill
Instance Method Details
#reference ⇒ Object
20
21
22
|
# File 'lib/ruby_drills/array/map_drill.rb', line 20
def reference
"@numbers.map {|x| x / 2}"
end
|
#setup ⇒ Object
3
4
5
6
7
|
# File 'lib/ruby_drills/array/map_drill.rb', line 3
def setup
@numbers = (0..10).to_a
@hints = ["You want to divide each member of this collection by two...",
"http://ruby-doc.org/core-1.9.3/Enumerable.html#method-i-map"]
end
|
#show ⇒ Object
9
10
11
12
13
14
15
16
17
18
|
# File 'lib/ruby_drills/array/map_drill.rb', line 9
def show
puts %{
@numbers = #{@numbers.inspect}
Use the method that returns a new array with the results of
running block once for every element in enum to produce
#{expected}
}
end
|
#valid?(input) ⇒ Boolean
24
25
26
|
# File 'lib/ruby_drills/array/map_drill.rb', line 24
def valid?(input)
['map', 'collect'].any? {|x| input.include? x}
end
|