Class: SplitDrill
- Inherits:
-
Drill
show all
- Defined in:
- lib/ruby_drills/string/split_drill.rb
Constant Summary
Constants included
from Commands
Commands::GAMBLER
Instance Attribute Summary
Attributes inherited from Drill
#hints, #next, #previous
Instance Method Summary
collapse
Methods inherited from Drill
#done?, #drills, #expected, #initialize, #non!
Methods included from Commands
#back, #clear, #continue, #fail, #fold, #help, #hint, #quit, #review, #skip, #welcome, #win
Constructor Details
This class inherits a constructor from Drill
Instance Method Details
#reference ⇒ Object
23
24
25
|
# File 'lib/ruby_drills/string/split_drill.rb', line 23
def reference
"@words.split('\n')"
end
|
#setup ⇒ Object
3
4
5
6
7
8
9
|
# File 'lib/ruby_drills/string/split_drill.rb', line 3
def setup
@words = %{under
the
ocean}
@hints = ["Use the newline char '\\n' as the splitting point. You'll need double quotes...",
"http://www.ruby-doc.org/core-1.9.3/String.html#method-i-split"]
end
|
#show ⇒ Object
11
12
13
14
15
16
17
18
19
20
21
|
# File 'lib/ruby_drills/string/split_drill.rb', line 11
def show
puts %{
@words = #{@words.inspect}
Take each line and make it the member of an array.
Use the method that will break up the string by the new line character,
and returns an array with each line as a member to produce
#{expected.inspect}:
}
end
|
#valid?(input) ⇒ Boolean
27
28
29
|
# File 'lib/ruby_drills/string/split_drill.rb', line 27
def valid?(input)
non!("split", input)
end
|